# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tradex.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='tradex.proto',
  package='TradeX',
  syntax='proto3',
  serialized_options=_b('\n\027io.grpc.examples.tradexB\013TradeXProtoP\001\242\002\003TDX'),
  serialized_pb=_b('\n\x0ctradex.proto\x12\x06TradeX\"!\n\x0bJSONRequest\x12\x12\n\nrqt_string\x18\x01 \x01(\t\"\"\n\x0cJSONResponse\x12\x12\n\nrsp_string\x18\x01 \x01(\t2\xec\x01\n\x06TradeX\x12\x37\n\x08SayHello\x12\x13.TradeX.JSONRequest\x1a\x14.TradeX.JSONResponse\"\x00\x12\x35\n\x06GetPos\x12\x13.TradeX.JSONRequest\x1a\x14.TradeX.JSONResponse\"\x00\x12\x38\n\tGetOrders\x12\x13.TradeX.JSONRequest\x1a\x14.TradeX.JSONResponse\"\x00\x12\x38\n\tSendOrder\x12\x13.TradeX.JSONRequest\x1a\x14.TradeX.JSONResponse\"\x00\x42.\n\x17io.grpc.examples.tradexB\x0bTradeXProtoP\x01\xa2\x02\x03TDXb\x06proto3')
)




_JSONREQUEST = _descriptor.Descriptor(
  name='JSONRequest',
  full_name='TradeX.JSONRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rqt_string', full_name='TradeX.JSONRequest.rqt_string', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24,
  serialized_end=57,
)


_JSONRESPONSE = _descriptor.Descriptor(
  name='JSONResponse',
  full_name='TradeX.JSONResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rsp_string', full_name='TradeX.JSONResponse.rsp_string', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=59,
  serialized_end=93,
)

DESCRIPTOR.message_types_by_name['JSONRequest'] = _JSONREQUEST
DESCRIPTOR.message_types_by_name['JSONResponse'] = _JSONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

JSONRequest = _reflection.GeneratedProtocolMessageType('JSONRequest', (_message.Message,), dict(
  DESCRIPTOR = _JSONREQUEST,
  __module__ = 'tradex_pb2'
  # @@protoc_insertion_point(class_scope:TradeX.JSONRequest)
  ))
_sym_db.RegisterMessage(JSONRequest)

JSONResponse = _reflection.GeneratedProtocolMessageType('JSONResponse', (_message.Message,), dict(
  DESCRIPTOR = _JSONRESPONSE,
  __module__ = 'tradex_pb2'
  # @@protoc_insertion_point(class_scope:TradeX.JSONResponse)
  ))
_sym_db.RegisterMessage(JSONResponse)


DESCRIPTOR._options = None

_TRADEX = _descriptor.ServiceDescriptor(
  name='TradeX',
  full_name='TradeX.TradeX',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=96,
  serialized_end=332,
  methods=[
  _descriptor.MethodDescriptor(
    name='SayHello',
    full_name='TradeX.TradeX.SayHello',
    index=0,
    containing_service=None,
    input_type=_JSONREQUEST,
    output_type=_JSONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetPos',
    full_name='TradeX.TradeX.GetPos',
    index=1,
    containing_service=None,
    input_type=_JSONREQUEST,
    output_type=_JSONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetOrders',
    full_name='TradeX.TradeX.GetOrders',
    index=2,
    containing_service=None,
    input_type=_JSONREQUEST,
    output_type=_JSONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SendOrder',
    full_name='TradeX.TradeX.SendOrder',
    index=3,
    containing_service=None,
    input_type=_JSONREQUEST,
    output_type=_JSONRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_TRADEX)

DESCRIPTOR.services_by_name['TradeX'] = _TRADEX

# @@protoc_insertion_point(module_scope)
