# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tradeApi.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor # pip install grpcio-tools
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='tradeApi.proto',
  package='Trade',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n\x0etradeApi.proto\x12\x05Trade\"@\n\tRspHeader\x12!\n\x08ret_type\x18\x01 \x01(\x0e\x32\x0f.Trade.RET_TYPE\x12\x10\n\x08sErrInfo\x18\x02 \x01(\t\"\x1b\n\x0bJSONRequest\x12\x0c\n\x04sReq\x18\x01 \x01(\t\"A\n\x0cJSONResponse\x12#\n\trspHeader\x18\x01 \x01(\x0b\x32\x10.Trade.RspHeader\x12\x0c\n\x04sRsp\x18\x02 \x01(\t\"\x8d\x01\n\x07PosItem\x12\x10\n\x08sStkCode\x18\x01 \x01(\t\x12\x1a\n\x06\x62sFlat\x18\x02 \x01(\x0e\x32\n.Trade.DIR\x12\x12\n\nfHoldPrice\x18\x03 \x01(\x02\x12\x0c\n\x04lQty\x18\x04 \x01(\x04\x12\x12\n\nlFrozenQty\x18\x05 \x01(\x04\x12\x0c\n\x04\x66\x41mt\x18\x06 \x01(\x02\x12\x10\n\x08sStkName\x18\x07 \x01(\t\"S\n\x0bRspPosition\x12#\n\trspHeader\x18\x01 \x01(\x0b\x32\x10.Trade.RspHeader\x12\x1f\n\x07posItem\x18\x02 \x03(\x0b\x32\x0e.Trade.PosItem\"\xdf\x02\n\tOrderItem\x12\x10\n\x08sOrderId\x18\x01 \x01(\t\x12\x10\n\x08sStkName\x18\x02 \x01(\t\x12\x12\n\nlOrderTime\x18\x03 \x01(\x04\x12\x1a\n\x06\x62sFlat\x18\x04 \x01(\x0e\x32\n.Trade.DIR\x12\x13\n\x0b\x66OrderPrice\x18\x05 \x01(\x02\x12\x11\n\tlOrderQty\x18\x06 \x01(\x04\x12\x13\n\x0blMatchedQty\x18\x07 \x01(\x04\x12\x15\n\rlWithdrawnQty\x18\x08 \x01(\x04\x12\x10\n\x08sStkCode\x18\t \x01(\t\x12\r\n\x05iDate\x18\n \x01(\x05\x12\'\n\nstatusInfo\x18\x0b \x01(\x0e\x32\x13.Trade.ORDER_STATUS\x12&\n\ncancelFlag\x18\x0c \x01(\x0e\x32\x12.Trade.CANCEL_FLAG\x12\x10\n\x08iErrCode\x18\r \x01(\x05\x12\x0f\n\x07sErrMsg\x18\x0e \x01(\t\x12\x15\n\rfMatchedPrice\x18\x0f \x01(\x02\"i\n\tRspOrders\x12#\n\trspHeader\x18\x01 \x01(\x0b\x32\x10.Trade.RspHeader\x12#\n\torderItem\x18\x02 \x03(\x0b\x32\x10.Trade.OrderItem\x12\x12\n\niTotalSize\x18\x03 \x01(\r\"/\n\x08ReqQuery\x12\x10\n\x08iPageNum\x18\x01 \x01(\r\x12\x11\n\tiPageSize\x18\x02 \x01(\r\"\x95\x02\n\tTransItem\x12\x10\n\x08sOrderId\x18\x01 \x01(\t\x12\x14\n\x0csMatchedTime\x18\x02 \x01(\t\x12\x13\n\x0b\x66MatchedAmt\x18\x03 \x01(\x02\x12\x1a\n\x06\x62sFlat\x18\x04 \x01(\x0e\x32\n.Trade.DIR\x12\x15\n\rfMatchedPrice\x18\x05 \x01(\x02\x12\x13\n\x0blMatchedQty\x18\x06 \x01(\x04\x12\x12\n\nsMatchedSn\x18\x07 \x01(\t\x12\x18\n\x10\x66TotalCommission\x18\x08 \x01(\x02\x12\x31\n\x0ftradeReportType\x18\t \x01(\x0e\x32\x18.Trade.TRADE_REPORT_TYPE\x12\x10\n\x08sStkCode\x18\n \x01(\t\x12\x10\n\x08sStkName\x18\x0b \x01(\t\"T\n\x08RspTrans\x12#\n\trspHeader\x18\x01 \x01(\x0b\x32\x10.Trade.RspHeader\x12#\n\ttransItem\x18\x02 \x03(\x0b\x32\x10.Trade.TransItem\"\x87\x01\n\x0cReqSentOrder\x12\r\n\x05sCode\x18\x01 \x01(\t\x12\x1a\n\x06\x62sFlat\x18\x02 \x01(\x0e\x32\n.Trade.DIR\x12$\n\torderType\x18\x03 \x01(\x0e\x32\x11.Trade.ORDER_TYPE\x12\x13\n\x0biOrderPrice\x18\x04 \x01(\r\x12\x11\n\tlOrderQty\x18\x05 \x01(\x04\"E\n\x0cRspSentOrder\x12#\n\trspHeader\x18\x01 \x01(\x0b\x32\x10.Trade.RspHeader\x12\x10\n\x08sOrderId\x18\x02 \x01(\t\"3\n\x0eReqCancelOrder\x12\x10\n\x08sOrderId\x18\x01 \x01(\t\x12\x0f\n\x07sMarket\x18\x02 \x01(\t\"5\n\x0eRspCancelOrder\x12#\n\trspHeader\x18\x01 \x01(\x0b\x32\x10.Trade.RspHeader*H\n\x08RET_TYPE\x12\x0b\n\x07SUCCESS\x10\x00\x12\x0e\n\nERR_NORMAL\x10\x01\x12\x0f\n\x0b\x45RR_SERIOUS\x10\x02\x12\x0e\n\nERR_IGNORE\x10\x03*#\n\nORDER_TYPE\x12\t\n\x05LIMIT\x10\x00\x12\n\n\x06MARKET\x10\x01*q\n\x0cORDER_STATUS\x12\x0b\n\x07PENDING\x10\x00\x12\n\n\x06TRADED\x10\x01\x12\x0f\n\x0bTRADED_PART\x10\x02\x12\x0e\n\nCANCEL_REQ\x10\x03\x12\x0c\n\x08\x43\x41NCELED\x10\x04\x12\x0c\n\x08REJECTED\x10\x05\x12\x0b\n\x07\x46\x41ILURE\x10\x06*6\n\x11TRADE_REPORT_TYPE\x12\n\n\x06NORMAL\x10\x00\x12\n\n\x06\x43\x41NCEL\x10\x01\x12\t\n\x05WASTE\x10\x02*,\n\x0b\x43\x41NCEL_FLAG\x12\x0e\n\nNOT_CANCEL\x10\x00\x12\r\n\tIS_CANCEL\x10\x01*,\n\x03\x44IR\x12\x07\n\x03\x42UY\x10\x00\x12\x08\n\x04SELL\x10\x01\x12\x08\n\x04\x42OTH\x10\x02\x12\x08\n\x04NULL\x10\x03\x32\xc5\x03\n\x05Trade\x12\x35\n\x08sayHello\x12\x12.Trade.JSONRequest\x1a\x13.Trade.JSONResponse\"\x00\x12\x32\n\x06getPos\x12\x12.Trade.JSONRequest\x1a\x12.Trade.RspPosition\"\x00\x12\x30\n\tgetOrders\x12\x0f.Trade.ReqQuery\x1a\x10.Trade.RspOrders\"\x00\x12.\n\x08getTrans\x12\x0f.Trade.ReqQuery\x1a\x0f.Trade.RspTrans\"\x00\x12;\n\x0fgetOrder_stream\x12\x12.Trade.JSONRequest\x1a\x10.Trade.RspOrders\"\x00\x30\x01\x12:\n\x0fgetTrans_stream\x12\x12.Trade.JSONRequest\x1a\x0f.Trade.RspTrans\"\x00\x30\x01\x12=\n\x0b\x63\x61ncelOrder\x12\x15.Trade.ReqCancelOrder\x1a\x15.Trade.RspCancelOrder\"\x00\x12\x37\n\tsendOrder\x12\x13.Trade.ReqSentOrder\x1a\x13.Trade.RspSentOrder\"\x00\x62\x06proto3'
)

_RET_TYPE = _descriptor.EnumDescriptor(
  name='RET_TYPE',
  full_name='Trade.RET_TYPE',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERR_NORMAL', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERR_SERIOUS', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERR_IGNORE', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1609,
  serialized_end=1681,
)
_sym_db.RegisterEnumDescriptor(_RET_TYPE)

RET_TYPE = enum_type_wrapper.EnumTypeWrapper(_RET_TYPE)
_ORDER_TYPE = _descriptor.EnumDescriptor(
  name='ORDER_TYPE',
  full_name='Trade.ORDER_TYPE',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LIMIT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MARKET', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1683,
  serialized_end=1718,
)
_sym_db.RegisterEnumDescriptor(_ORDER_TYPE)

ORDER_TYPE = enum_type_wrapper.EnumTypeWrapper(_ORDER_TYPE)
_ORDER_STATUS = _descriptor.EnumDescriptor(
  name='ORDER_STATUS',
  full_name='Trade.ORDER_STATUS',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRADED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRADED_PART', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANCEL_REQ', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANCELED', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REJECTED', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILURE', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1720,
  serialized_end=1833,
)
_sym_db.RegisterEnumDescriptor(_ORDER_STATUS)

ORDER_STATUS = enum_type_wrapper.EnumTypeWrapper(_ORDER_STATUS)
_TRADE_REPORT_TYPE = _descriptor.EnumDescriptor(
  name='TRADE_REPORT_TYPE',
  full_name='Trade.TRADE_REPORT_TYPE',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NORMAL', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANCEL', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WASTE', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1835,
  serialized_end=1889,
)
_sym_db.RegisterEnumDescriptor(_TRADE_REPORT_TYPE)

TRADE_REPORT_TYPE = enum_type_wrapper.EnumTypeWrapper(_TRADE_REPORT_TYPE)
_CANCEL_FLAG = _descriptor.EnumDescriptor(
  name='CANCEL_FLAG',
  full_name='Trade.CANCEL_FLAG',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOT_CANCEL', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IS_CANCEL', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1891,
  serialized_end=1935,
)
_sym_db.RegisterEnumDescriptor(_CANCEL_FLAG)

CANCEL_FLAG = enum_type_wrapper.EnumTypeWrapper(_CANCEL_FLAG)
_DIR = _descriptor.EnumDescriptor(
  name='DIR',
  full_name='Trade.DIR',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BUY', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SELL', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOTH', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NULL', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1937,
  serialized_end=1981,
)
_sym_db.RegisterEnumDescriptor(_DIR)

DIR = enum_type_wrapper.EnumTypeWrapper(_DIR)
SUCCESS = 0
ERR_NORMAL = 1
ERR_SERIOUS = 2
ERR_IGNORE = 3
LIMIT = 0
MARKET = 1
PENDING = 0
TRADED = 1
TRADED_PART = 2
CANCEL_REQ = 3
CANCELED = 4
REJECTED = 5
FAILURE = 6
NORMAL = 0
CANCEL = 1
WASTE = 2
NOT_CANCEL = 0
IS_CANCEL = 1
BUY = 0
SELL = 1
BOTH = 2
NULL = 3



_RSPHEADER = _descriptor.Descriptor(
  name='RspHeader',
  full_name='Trade.RspHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ret_type', full_name='Trade.RspHeader.ret_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sErrInfo', full_name='Trade.RspHeader.sErrInfo', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25,
  serialized_end=89,
)


_JSONREQUEST = _descriptor.Descriptor(
  name='JSONRequest',
  full_name='Trade.JSONRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sReq', full_name='Trade.JSONRequest.sReq', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=91,
  serialized_end=118,
)


_JSONRESPONSE = _descriptor.Descriptor(
  name='JSONResponse',
  full_name='Trade.JSONResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rspHeader', full_name='Trade.JSONResponse.rspHeader', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sRsp', full_name='Trade.JSONResponse.sRsp', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=120,
  serialized_end=185,
)


_POSITEM = _descriptor.Descriptor(
  name='PosItem',
  full_name='Trade.PosItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sStkCode', full_name='Trade.PosItem.sStkCode', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bsFlat', full_name='Trade.PosItem.bsFlat', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fHoldPrice', full_name='Trade.PosItem.fHoldPrice', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lQty', full_name='Trade.PosItem.lQty', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lFrozenQty', full_name='Trade.PosItem.lFrozenQty', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fAmt', full_name='Trade.PosItem.fAmt', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sStkName', full_name='Trade.PosItem.sStkName', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=188,
  serialized_end=329,
)


_RSPPOSITION = _descriptor.Descriptor(
  name='RspPosition',
  full_name='Trade.RspPosition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rspHeader', full_name='Trade.RspPosition.rspHeader', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='posItem', full_name='Trade.RspPosition.posItem', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=331,
  serialized_end=414,
)


_ORDERITEM = _descriptor.Descriptor(
  name='OrderItem',
  full_name='Trade.OrderItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sOrderId', full_name='Trade.OrderItem.sOrderId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sStkName', full_name='Trade.OrderItem.sStkName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lOrderTime', full_name='Trade.OrderItem.lOrderTime', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bsFlat', full_name='Trade.OrderItem.bsFlat', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fOrderPrice', full_name='Trade.OrderItem.fOrderPrice', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lOrderQty', full_name='Trade.OrderItem.lOrderQty', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lMatchedQty', full_name='Trade.OrderItem.lMatchedQty', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lWithdrawnQty', full_name='Trade.OrderItem.lWithdrawnQty', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sStkCode', full_name='Trade.OrderItem.sStkCode', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='iDate', full_name='Trade.OrderItem.iDate', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='statusInfo', full_name='Trade.OrderItem.statusInfo', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cancelFlag', full_name='Trade.OrderItem.cancelFlag', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='iErrCode', full_name='Trade.OrderItem.iErrCode', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sErrMsg', full_name='Trade.OrderItem.sErrMsg', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fMatchedPrice', full_name='Trade.OrderItem.fMatchedPrice', index=14,
      number=15, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=417,
  serialized_end=768,
)


_RSPORDERS = _descriptor.Descriptor(
  name='RspOrders',
  full_name='Trade.RspOrders',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rspHeader', full_name='Trade.RspOrders.rspHeader', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='orderItem', full_name='Trade.RspOrders.orderItem', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='iTotalSize', full_name='Trade.RspOrders.iTotalSize', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=770,
  serialized_end=875,
)


_REQQUERY = _descriptor.Descriptor(
  name='ReqQuery',
  full_name='Trade.ReqQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='iPageNum', full_name='Trade.ReqQuery.iPageNum', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='iPageSize', full_name='Trade.ReqQuery.iPageSize', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=877,
  serialized_end=924,
)


_TRANSITEM = _descriptor.Descriptor(
  name='TransItem',
  full_name='Trade.TransItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sOrderId', full_name='Trade.TransItem.sOrderId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sMatchedTime', full_name='Trade.TransItem.sMatchedTime', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fMatchedAmt', full_name='Trade.TransItem.fMatchedAmt', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bsFlat', full_name='Trade.TransItem.bsFlat', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fMatchedPrice', full_name='Trade.TransItem.fMatchedPrice', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lMatchedQty', full_name='Trade.TransItem.lMatchedQty', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sMatchedSn', full_name='Trade.TransItem.sMatchedSn', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fTotalCommission', full_name='Trade.TransItem.fTotalCommission', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tradeReportType', full_name='Trade.TransItem.tradeReportType', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sStkCode', full_name='Trade.TransItem.sStkCode', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sStkName', full_name='Trade.TransItem.sStkName', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=927,
  serialized_end=1204,
)


_RSPTRANS = _descriptor.Descriptor(
  name='RspTrans',
  full_name='Trade.RspTrans',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rspHeader', full_name='Trade.RspTrans.rspHeader', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transItem', full_name='Trade.RspTrans.transItem', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1206,
  serialized_end=1290,
)


_REQSENTORDER = _descriptor.Descriptor(
  name='ReqSentOrder',
  full_name='Trade.ReqSentOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sCode', full_name='Trade.ReqSentOrder.sCode', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bsFlat', full_name='Trade.ReqSentOrder.bsFlat', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='orderType', full_name='Trade.ReqSentOrder.orderType', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='iOrderPrice', full_name='Trade.ReqSentOrder.iOrderPrice', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lOrderQty', full_name='Trade.ReqSentOrder.lOrderQty', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1293,
  serialized_end=1428,
)


_RSPSENTORDER = _descriptor.Descriptor(
  name='RspSentOrder',
  full_name='Trade.RspSentOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rspHeader', full_name='Trade.RspSentOrder.rspHeader', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sOrderId', full_name='Trade.RspSentOrder.sOrderId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1430,
  serialized_end=1499,
)


_REQCANCELORDER = _descriptor.Descriptor(
  name='ReqCancelOrder',
  full_name='Trade.ReqCancelOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sOrderId', full_name='Trade.ReqCancelOrder.sOrderId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sMarket', full_name='Trade.ReqCancelOrder.sMarket', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1501,
  serialized_end=1552,
)


_RSPCANCELORDER = _descriptor.Descriptor(
  name='RspCancelOrder',
  full_name='Trade.RspCancelOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rspHeader', full_name='Trade.RspCancelOrder.rspHeader', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1554,
  serialized_end=1607,
)

_RSPHEADER.fields_by_name['ret_type'].enum_type = _RET_TYPE
_JSONRESPONSE.fields_by_name['rspHeader'].message_type = _RSPHEADER
_POSITEM.fields_by_name['bsFlat'].enum_type = _DIR
_RSPPOSITION.fields_by_name['rspHeader'].message_type = _RSPHEADER
_RSPPOSITION.fields_by_name['posItem'].message_type = _POSITEM
_ORDERITEM.fields_by_name['bsFlat'].enum_type = _DIR
_ORDERITEM.fields_by_name['statusInfo'].enum_type = _ORDER_STATUS
_ORDERITEM.fields_by_name['cancelFlag'].enum_type = _CANCEL_FLAG
_RSPORDERS.fields_by_name['rspHeader'].message_type = _RSPHEADER
_RSPORDERS.fields_by_name['orderItem'].message_type = _ORDERITEM
_TRANSITEM.fields_by_name['bsFlat'].enum_type = _DIR
_TRANSITEM.fields_by_name['tradeReportType'].enum_type = _TRADE_REPORT_TYPE
_RSPTRANS.fields_by_name['rspHeader'].message_type = _RSPHEADER
_RSPTRANS.fields_by_name['transItem'].message_type = _TRANSITEM
_REQSENTORDER.fields_by_name['bsFlat'].enum_type = _DIR
_REQSENTORDER.fields_by_name['orderType'].enum_type = _ORDER_TYPE
_RSPSENTORDER.fields_by_name['rspHeader'].message_type = _RSPHEADER
_RSPCANCELORDER.fields_by_name['rspHeader'].message_type = _RSPHEADER
DESCRIPTOR.message_types_by_name['RspHeader'] = _RSPHEADER
DESCRIPTOR.message_types_by_name['JSONRequest'] = _JSONREQUEST
DESCRIPTOR.message_types_by_name['JSONResponse'] = _JSONRESPONSE
DESCRIPTOR.message_types_by_name['PosItem'] = _POSITEM
DESCRIPTOR.message_types_by_name['RspPosition'] = _RSPPOSITION
DESCRIPTOR.message_types_by_name['OrderItem'] = _ORDERITEM
DESCRIPTOR.message_types_by_name['RspOrders'] = _RSPORDERS
DESCRIPTOR.message_types_by_name['ReqQuery'] = _REQQUERY
DESCRIPTOR.message_types_by_name['TransItem'] = _TRANSITEM
DESCRIPTOR.message_types_by_name['RspTrans'] = _RSPTRANS
DESCRIPTOR.message_types_by_name['ReqSentOrder'] = _REQSENTORDER
DESCRIPTOR.message_types_by_name['RspSentOrder'] = _RSPSENTORDER
DESCRIPTOR.message_types_by_name['ReqCancelOrder'] = _REQCANCELORDER
DESCRIPTOR.message_types_by_name['RspCancelOrder'] = _RSPCANCELORDER
DESCRIPTOR.enum_types_by_name['RET_TYPE'] = _RET_TYPE
DESCRIPTOR.enum_types_by_name['ORDER_TYPE'] = _ORDER_TYPE
DESCRIPTOR.enum_types_by_name['ORDER_STATUS'] = _ORDER_STATUS
DESCRIPTOR.enum_types_by_name['TRADE_REPORT_TYPE'] = _TRADE_REPORT_TYPE
DESCRIPTOR.enum_types_by_name['CANCEL_FLAG'] = _CANCEL_FLAG
DESCRIPTOR.enum_types_by_name['DIR'] = _DIR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RspHeader = _reflection.GeneratedProtocolMessageType('RspHeader', (_message.Message,), {
  'DESCRIPTOR' : _RSPHEADER,
  '__module__' : 'tradeApi_pb2'
  # @@protoc_insertion_point(class_scope:Trade.RspHeader)
  })
_sym_db.RegisterMessage(RspHeader)

JSONRequest = _reflection.GeneratedProtocolMessageType('JSONRequest', (_message.Message,), {
  'DESCRIPTOR' : _JSONREQUEST,
  '__module__' : 'tradeApi_pb2'
  # @@protoc_insertion_point(class_scope:Trade.JSONRequest)
  })
_sym_db.RegisterMessage(JSONRequest)

JSONResponse = _reflection.GeneratedProtocolMessageType('JSONResponse', (_message.Message,), {
  'DESCRIPTOR' : _JSONRESPONSE,
  '__module__' : 'tradeApi_pb2'
  # @@protoc_insertion_point(class_scope:Trade.JSONResponse)
  })
_sym_db.RegisterMessage(JSONResponse)

PosItem = _reflection.GeneratedProtocolMessageType('PosItem', (_message.Message,), {
  'DESCRIPTOR' : _POSITEM,
  '__module__' : 'tradeApi_pb2'
  # @@protoc_insertion_point(class_scope:Trade.PosItem)
  })
_sym_db.RegisterMessage(PosItem)

RspPosition = _reflection.GeneratedProtocolMessageType('RspPosition', (_message.Message,), {
  'DESCRIPTOR' : _RSPPOSITION,
  '__module__' : 'tradeApi_pb2'
  # @@protoc_insertion_point(class_scope:Trade.RspPosition)
  })
_sym_db.RegisterMessage(RspPosition)

OrderItem = _reflection.GeneratedProtocolMessageType('OrderItem', (_message.Message,), {
  'DESCRIPTOR' : _ORDERITEM,
  '__module__' : 'tradeApi_pb2'
  # @@protoc_insertion_point(class_scope:Trade.OrderItem)
  })
_sym_db.RegisterMessage(OrderItem)

RspOrders = _reflection.GeneratedProtocolMessageType('RspOrders', (_message.Message,), {
  'DESCRIPTOR' : _RSPORDERS,
  '__module__' : 'tradeApi_pb2'
  # @@protoc_insertion_point(class_scope:Trade.RspOrders)
  })
_sym_db.RegisterMessage(RspOrders)

ReqQuery = _reflection.GeneratedProtocolMessageType('ReqQuery', (_message.Message,), {
  'DESCRIPTOR' : _REQQUERY,
  '__module__' : 'tradeApi_pb2'
  # @@protoc_insertion_point(class_scope:Trade.ReqQuery)
  })
_sym_db.RegisterMessage(ReqQuery)

TransItem = _reflection.GeneratedProtocolMessageType('TransItem', (_message.Message,), {
  'DESCRIPTOR' : _TRANSITEM,
  '__module__' : 'tradeApi_pb2'
  # @@protoc_insertion_point(class_scope:Trade.TransItem)
  })
_sym_db.RegisterMessage(TransItem)

RspTrans = _reflection.GeneratedProtocolMessageType('RspTrans', (_message.Message,), {
  'DESCRIPTOR' : _RSPTRANS,
  '__module__' : 'tradeApi_pb2'
  # @@protoc_insertion_point(class_scope:Trade.RspTrans)
  })
_sym_db.RegisterMessage(RspTrans)

ReqSentOrder = _reflection.GeneratedProtocolMessageType('ReqSentOrder', (_message.Message,), {
  'DESCRIPTOR' : _REQSENTORDER,
  '__module__' : 'tradeApi_pb2'
  # @@protoc_insertion_point(class_scope:Trade.ReqSentOrder)
  })
_sym_db.RegisterMessage(ReqSentOrder)

RspSentOrder = _reflection.GeneratedProtocolMessageType('RspSentOrder', (_message.Message,), {
  'DESCRIPTOR' : _RSPSENTORDER,
  '__module__' : 'tradeApi_pb2'
  # @@protoc_insertion_point(class_scope:Trade.RspSentOrder)
  })
_sym_db.RegisterMessage(RspSentOrder)

ReqCancelOrder = _reflection.GeneratedProtocolMessageType('ReqCancelOrder', (_message.Message,), {
  'DESCRIPTOR' : _REQCANCELORDER,
  '__module__' : 'tradeApi_pb2'
  # @@protoc_insertion_point(class_scope:Trade.ReqCancelOrder)
  })
_sym_db.RegisterMessage(ReqCancelOrder)

RspCancelOrder = _reflection.GeneratedProtocolMessageType('RspCancelOrder', (_message.Message,), {
  'DESCRIPTOR' : _RSPCANCELORDER,
  '__module__' : 'tradeApi_pb2'
  # @@protoc_insertion_point(class_scope:Trade.RspCancelOrder)
  })
_sym_db.RegisterMessage(RspCancelOrder)



_TRADE = _descriptor.ServiceDescriptor(
  name='Trade',
  full_name='Trade.Trade',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1984,
  serialized_end=2437,
  methods=[
  _descriptor.MethodDescriptor(
    name='sayHello',
    full_name='Trade.Trade.sayHello',
    index=0,
    containing_service=None,
    input_type=_JSONREQUEST,
    output_type=_JSONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getPos',
    full_name='Trade.Trade.getPos',
    index=1,
    containing_service=None,
    input_type=_JSONREQUEST,
    output_type=_RSPPOSITION,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getOrders',
    full_name='Trade.Trade.getOrders',
    index=2,
    containing_service=None,
    input_type=_REQQUERY,
    output_type=_RSPORDERS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getTrans',
    full_name='Trade.Trade.getTrans',
    index=3,
    containing_service=None,
    input_type=_REQQUERY,
    output_type=_RSPTRANS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getOrder_stream',
    full_name='Trade.Trade.getOrder_stream',
    index=4,
    containing_service=None,
    input_type=_JSONREQUEST,
    output_type=_RSPORDERS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getTrans_stream',
    full_name='Trade.Trade.getTrans_stream',
    index=5,
    containing_service=None,
    input_type=_JSONREQUEST,
    output_type=_RSPTRANS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='cancelOrder',
    full_name='Trade.Trade.cancelOrder',
    index=6,
    containing_service=None,
    input_type=_REQCANCELORDER,
    output_type=_RSPCANCELORDER,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='sendOrder',
    full_name='Trade.Trade.sendOrder',
    index=7,
    containing_service=None,
    input_type=_REQSENTORDER,
    output_type=_RSPSENTORDER,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_TRADE)

DESCRIPTOR.services_by_name['Trade'] = _TRADE

# @@protoc_insertion_point(module_scope)
