# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: indexData.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='indexData.proto',
  package='indexData',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x0findexData.proto\x12\tindexData\"D\n\tRspHeader\x12%\n\x08ret_type\x18\x01 \x01(\x0e\x32\x13.indexData.RET_TYPE\x12\x10\n\x08sErrInfo\x18\x02 \x01(\t\"\x1b\n\x0bJSONRequest\x12\x0c\n\x04sReq\x18\x01 \x01(\t\"E\n\x0cJSONResponse\x12\'\n\trspHeader\x18\x01 \x01(\x0b\x32\x14.indexData.RspHeader\x12\x0c\n\x04sRsp\x18\x02 \x01(\t\"B\n\x07Symbols\x12\'\n\trspHeader\x18\x01 \x01(\x0b\x32\x14.indexData.RspHeader\x12\x0e\n\x06symbol\x18\x02 \x03(\t*H\n\x08RET_TYPE\x12\x0b\n\x07SUCCESS\x10\x00\x12\x0e\n\nERR_NORMAL\x10\x01\x12\x0f\n\x0b\x45RR_SERIOUS\x10\x02\x12\x0e\n\nERR_IGNORE\x10\x03\x32\x86\x01\n\tindexData\x12=\n\x08sayHello\x12\x16.indexData.JSONRequest\x1a\x17.indexData.JSONResponse\"\x00\x12:\n\ngetSymbols\x12\x16.indexData.JSONRequest\x1a\x12.indexData.Symbols\"\x00\x62\x06proto3')
)

_RET_TYPE = _descriptor.EnumDescriptor(
  name='RET_TYPE',
  full_name='indexData.RET_TYPE',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERR_NORMAL', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERR_SERIOUS', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERR_IGNORE', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=268,
  serialized_end=340,
)
_sym_db.RegisterEnumDescriptor(_RET_TYPE)

RET_TYPE = enum_type_wrapper.EnumTypeWrapper(_RET_TYPE)
SUCCESS = 0
ERR_NORMAL = 1
ERR_SERIOUS = 2
ERR_IGNORE = 3



_RSPHEADER = _descriptor.Descriptor(
  name='RspHeader',
  full_name='indexData.RspHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ret_type', full_name='indexData.RspHeader.ret_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sErrInfo', full_name='indexData.RspHeader.sErrInfo', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=30,
  serialized_end=98,
)


_JSONREQUEST = _descriptor.Descriptor(
  name='JSONRequest',
  full_name='indexData.JSONRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sReq', full_name='indexData.JSONRequest.sReq', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=100,
  serialized_end=127,
)


_JSONRESPONSE = _descriptor.Descriptor(
  name='JSONResponse',
  full_name='indexData.JSONResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rspHeader', full_name='indexData.JSONResponse.rspHeader', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sRsp', full_name='indexData.JSONResponse.sRsp', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=129,
  serialized_end=198,
)


_SYMBOLS = _descriptor.Descriptor(
  name='Symbols',
  full_name='indexData.Symbols',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rspHeader', full_name='indexData.Symbols.rspHeader', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='indexData.Symbols.symbol', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=200,
  serialized_end=266,
)

_RSPHEADER.fields_by_name['ret_type'].enum_type = _RET_TYPE
_JSONRESPONSE.fields_by_name['rspHeader'].message_type = _RSPHEADER
_SYMBOLS.fields_by_name['rspHeader'].message_type = _RSPHEADER
DESCRIPTOR.message_types_by_name['RspHeader'] = _RSPHEADER
DESCRIPTOR.message_types_by_name['JSONRequest'] = _JSONREQUEST
DESCRIPTOR.message_types_by_name['JSONResponse'] = _JSONRESPONSE
DESCRIPTOR.message_types_by_name['Symbols'] = _SYMBOLS
DESCRIPTOR.enum_types_by_name['RET_TYPE'] = _RET_TYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RspHeader = _reflection.GeneratedProtocolMessageType('RspHeader', (_message.Message,), dict(
  DESCRIPTOR = _RSPHEADER,
  __module__ = 'indexData_pb2'
  # @@protoc_insertion_point(class_scope:indexData.RspHeader)
  ))
_sym_db.RegisterMessage(RspHeader)

JSONRequest = _reflection.GeneratedProtocolMessageType('JSONRequest', (_message.Message,), dict(
  DESCRIPTOR = _JSONREQUEST,
  __module__ = 'indexData_pb2'
  # @@protoc_insertion_point(class_scope:indexData.JSONRequest)
  ))
_sym_db.RegisterMessage(JSONRequest)

JSONResponse = _reflection.GeneratedProtocolMessageType('JSONResponse', (_message.Message,), dict(
  DESCRIPTOR = _JSONRESPONSE,
  __module__ = 'indexData_pb2'
  # @@protoc_insertion_point(class_scope:indexData.JSONResponse)
  ))
_sym_db.RegisterMessage(JSONResponse)

Symbols = _reflection.GeneratedProtocolMessageType('Symbols', (_message.Message,), dict(
  DESCRIPTOR = _SYMBOLS,
  __module__ = 'indexData_pb2'
  # @@protoc_insertion_point(class_scope:indexData.Symbols)
  ))
_sym_db.RegisterMessage(Symbols)



_INDEXDATA = _descriptor.ServiceDescriptor(
  name='indexData',
  full_name='indexData.indexData',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=343,
  serialized_end=477,
  methods=[
  _descriptor.MethodDescriptor(
    name='sayHello',
    full_name='indexData.indexData.sayHello',
    index=0,
    containing_service=None,
    input_type=_JSONREQUEST,
    output_type=_JSONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getSymbols',
    full_name='indexData.indexData.getSymbols',
    index=1,
    containing_service=None,
    input_type=_JSONREQUEST,
    output_type=_SYMBOLS,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_INDEXDATA)

DESCRIPTOR.services_by_name['indexData'] = _INDEXDATA

# @@protoc_insertion_point(module_scope)
